@@ -1,12 +1,12 @@
 package File::Copy::Undoable;
 
-our $DATE = '2016-06-10'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 use IPC::System::Options 'system', -log=>1;
 use File::MoreUtil qw(file_exists);
@@ -115,7 +115,7 @@ sub cp {
             # transfer, so we allow target to exist
             return [304, "Target $target already exists"] if $te;
         }
-        $log->info("(DRY) ".
+        log_info("(DRY) ".
                        ($te ? "Syncing" : "Copying")." $source -> $target ...")
             if $dry_run;
         return [200, "$source needs to be ".($te ? "synced":"copied").
@@ -125,12 +125,12 @@ sub cp {
 
     } elsif ($tx_action eq 'fix_state') {
         my @cmd = ("rsync", @$rsync_opts, "$source/", "$target/");
-        $log->info("Rsync-ing $source -> $target ...");
+        log_info("Rsync-ing $source -> $target ...");
         system @cmd;
         return [500, "Can't rsync: ".explain_child_error($?)] if $?;
         if (defined($args{target_owner}) || defined($args{target_group})) {
             if ($> == 0) {
-                $log->info("Chown-ing $target ...");
+                log_info("Chown-ing $target ...");
                 @cmd = (
                     "chown", "-Rh",
                     join("", $args{target_owner}//"", ":",
@@ -139,7 +139,7 @@ sub cp {
                 system @cmd;
                 return [500, "Can't chown: ".explain_child_error($?)] if $?;
             } else {
-                $log->debug("Not running as root, not doing chown");
+                log_debug("Not running as root, not doing chown");
             }
         }
         return [200, "OK"];
@@ -162,12 +162,16 @@ File::Copy::Undoable - Copy file/directory using rsync, with undo support
 
 =head1 VERSION
 
-This document describes version 0.11 of File::Copy::Undoable (from Perl distribution File-Copy-Undoable), released on 2016-06-10.
+This document describes version 0.12 of File::Copy::Undoable (from Perl distribution File-Copy-Undoable), released on 2017-07-10.
 
 =head1 FUNCTIONS
 
 
-=head2 cp(%args) -> [status, msg, result, meta]
+=head2 cp
+
+Usage:
+
+ cp(%args) -> [status, msg, result, meta]
 
 Copy file/directory using rsync, with undo support.
 
@@ -300,7 +304,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
